@@ -13,7 +13,7 @@ def cookie_to_dict(cookies: str) -> dict:
     :param cookies: cookie字符串
     :return: dict
     """
-    return {cookie.split('=')[0]: cookie.split('=')[-1] for cookie in cookies.split('; ')}
+    return dict(x.split('=') for x in cookies.split('; '))  # noqa
 
 
 def headers_to_dict(headers: str) -> dict:
@@ -22,12 +22,7 @@ def headers_to_dict(headers: str) -> dict:
     :param headers: headers字符串
     :return: dict
     """
-    header_dict = {}
-    for line in headers.split('\n'):
-        if ':' in line:
-            key, value = line.split(':', 1)
-            header_dict[key.strip()] = value.strip()
-    return header_dict
+    return dict(map(lambda x: x.strip(), line.split(':')) for line in headers.split('\n') if ':' in line)  # noqa
 
 
 def data_to_dict(data: str) -> dict:
@@ -36,7 +31,7 @@ def data_to_dict(data: str) -> dict:
     :param data: data字符串。格式为`key1=value1&key2=value2`
     :return: dict
     """
-    return {item.split('=')[0]: item.split('=')[-1] for item in data.split('&')}
+    return dict(x.split('=') for x in data.split('&'))  # noqa
 
 
 def gen_unique_id():
